[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- edist: edist - Simple command line coordinate processing.
- upoints: upoints - Modules for working with points on Earth.
  - upoints.baken: baken - Imports baken data files
  - upoints.cellid: cellid - Imports OpenCellID data files
  - upoints.cities: cities - Imports GNU miscfiles cities data files
  - upoints.geonames: geonames - Imports geonames.org data files
  - upoints.gpx: gpx - Imports GPS eXchange format data files
  - upoints.kml: kml - Imports KML data files
  - upoints.nmea: nmea - Imports GPS NMEA-formatted data files
  - upoints.osm: osm - Imports OpenStreetMap data files
  - upoints.point: point - Class for working with locations on Earth
  - upoints.trigpoints: trigpoints - Imports trigpoint marker files
  - upoints.tzdata: tzdata - Imports timezone data files from UNIX zoneinfo
  - upoints.utils: utils - Support code for upoints
  - upoints.weather_stations: weather_stations - Imports weather station data files
  - upoints.xearth: xearth - Imports xearth-style marker files